==> kubernetes-model-core-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/FCVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface FCVolumeSourceFluent<A extends FCVolumeSourceFluent<A>> extends Fluent<A>{
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  public Integer getLun();
  public A withLun(Integer lun);
  public Boolean hasLun();
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  public A addToTargetWWNs(Integer index,String item);
  public A setToTargetWWNs(Integer index,String item);
  public A addToTargetWWNs(java.lang.String... items);
  public A addAllToTargetWWNs(Collection<String> items);
  public A removeFromTargetWWNs(java.lang.String... items);
  public A removeAllFromTargetWWNs(Collection<String> items);
  public List<String> getTargetWWNs();
  public String getTargetWWN(Integer index);
  public String getFirstTargetWWN();
  public String getLastTargetWWN();
  public String getMatchingTargetWWN(Predicate<String> predicate);
  public Boolean hasMatchingTargetWWN(Predicate<String> predicate);
  public A withTargetWWNs(List<String> targetWWNs);
  public A withTargetWWNs(java.lang.String... targetWWNs);
  public Boolean hasTargetWWNs();
  public A addToWwids(Integer index,String item);
  public A setToWwids(Integer index,String item);
  public A addToWwids(java.lang.String... items);
  public A addAllToWwids(Collection<String> items);
  public A removeFromWwids(java.lang.String... items);
  public A removeAllFromWwids(Collection<String> items);
  public List<String> getWwids();
  public String getWwid(Integer index);
  public String getFirstWwid();
  public String getLastWwid();
  public String getMatchingWwid(Predicate<String> predicate);
  public Boolean hasMatchingWwid(Predicate<String> predicate);
  public A withWwids(List<String> wwids);
  public A withWwids(java.lang.String... wwids);
  public Boolean hasWwids();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  
}

==> kubernetes-model-core-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/FCVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface FCVolumeSourceFluent<A extends FCVolumeSourceFluent<A>> extends Fluent<A>{
  public String getFsType();
  public A withFsType(String fsType);
  public Boolean hasFsType();
  public Integer getLun();
  public A withLun(Integer lun);
  public Boolean hasLun();
  public Boolean getReadOnly();
  public A withReadOnly(Boolean readOnly);
  public Boolean hasReadOnly();
  public A addToTargetWWNs(int index,String item);
  public A setToTargetWWNs(int index,String item);
  public A addToTargetWWNs(java.lang.String... items);
  public A addAllToTargetWWNs(Collection<String> items);
  public A removeFromTargetWWNs(java.lang.String... items);
  public A removeAllFromTargetWWNs(Collection<String> items);
  public List<String> getTargetWWNs();
  public String getTargetWWN(int index);
  public String getFirstTargetWWN();
  public String getLastTargetWWN();
  public String getMatchingTargetWWN(Predicate<String> predicate);
  public Boolean hasMatchingTargetWWN(Predicate<String> predicate);
  public A withTargetWWNs(List<String> targetWWNs);
  public A withTargetWWNs(java.lang.String... targetWWNs);
  public Boolean hasTargetWWNs();
  public A addToWwids(int index,String item);
  public A setToWwids(int index,String item);
  public A addToWwids(java.lang.String... items);
  public A addAllToWwids(Collection<String> items);
  public A removeFromWwids(java.lang.String... items);
  public A removeAllFromWwids(Collection<String> items);
  public List<String> getWwids();
  public String getWwid(int index);
  public String getFirstWwid();
  public String getLastWwid();
  public String getMatchingWwid(Predicate<String> predicate);
  public Boolean hasMatchingWwid(Predicate<String> predicate);
  public A withWwids(List<String> wwids);
  public A withWwids(java.lang.String... wwids);
  public Boolean hasWwids();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withReadOnly();
  
}
